@@ -1,4 +1,5 @@
 import abc
+import builtins
 import datetime
 import enum
 import typing
@@ -7,17 +8,15 @@ import jsii
 import jsii.compat
 import publication
 
-from jsii.python import classproperty
-
-import aws_cdk.assets
 import aws_cdk.aws_cloudwatch
 import aws_cdk.aws_ec2
 import aws_cdk.aws_events
 import aws_cdk.aws_iam
 import aws_cdk.aws_logs
 import aws_cdk.aws_s3
+import aws_cdk.aws_s3_assets
 import aws_cdk.aws_sqs
-import aws_cdk.cdk
+import aws_cdk.core
 import aws_cdk.cx_api
 __all__ = []
 
